[PATCH] rtems: Use identifier instead of designator

Sebastian Huber sebastian.huber at embedded-brains.de
Thu Nov 18 18:58:42 UTC 2021


The term identifier is better aligned with the C11 standard wording.
---
 cpukit/include/rtems/rtems/intr.h | 24 ++++++++++++------------
 1 file changed, 12 insertions(+), 12 deletions(-)

diff --git a/cpukit/include/rtems/rtems/intr.h b/cpukit/include/rtems/rtems/intr.h
index d0aaed5f30..2c88d1265d 100644
--- a/cpukit/include/rtems/rtems/intr.h
+++ b/cpukit/include/rtems/rtems/intr.h
@@ -810,13 +810,13 @@ rtems_status_code rtems_interrupt_catch(
  * @param _specifier is the storage-class specifier for the ISR lock to
  *   declare, for example ``extern`` or ``static``.
  *
  * @param _designator is the ISR lock object designator.
  *
  * @par Notes
  * Do not add a ";" after this macro.
  */
-#define RTEMS_INTERRUPT_LOCK_DECLARE( _specifier, _designator ) \
-  ISR_LOCK_DECLARE( _specifier, _designator )
+#define RTEMS_INTERRUPT_LOCK_DECLARE( _specifier, _identifier ) \
+  ISR_LOCK_DECLARE( _specifier, _identifier )
 
 /* Generated from spec:/rtems/intr/if/lock-define */
 
@@ -828,7 +828,7 @@ rtems_status_code rtems_interrupt_catch(
  * @param _specifier is the storage-class specifier for the ISR lock to
  *   declare, for example ``extern`` or ``static``.
  *
  * @param _designator is the ISR lock object designator.
  *
  * @param _name is the ISR lock name.  It shall be a string.  The name is only
  *   used where the system was built with profiling support enabled.
@@ -842,8 +842,8 @@ rtems_status_code rtems_interrupt_catch(
  * RTEMS_INTERRUPT_LOCK_INITIALIZER().
  * @endparblock
  */
-#define RTEMS_INTERRUPT_LOCK_DEFINE( _specifier, _designator, _name ) \
-  ISR_LOCK_DEFINE( _specifier, _designator, _name )
+#define RTEMS_INTERRUPT_LOCK_DEFINE( _specifier, _identifier, _name ) \
+  ISR_LOCK_DEFINE( _specifier, _identifier, _name )
 
 /* Generated from spec:/rtems/intr/if/lock-initializer */
 
@@ -869,13 +869,13 @@ rtems_status_code rtems_interrupt_catch(
  *
  * @brief Defines an ISR lock member.
  *
  * @param _designator is the ISR lock member designator.
  *
  * @par Notes
  * Do not add a ";" after this macro.
  */
-#define RTEMS_INTERRUPT_LOCK_MEMBER( _designator ) \
-  ISR_LOCK_MEMBER( _designator )
+#define RTEMS_INTERRUPT_LOCK_MEMBER( _identifier ) \
+  ISR_LOCK_MEMBER( _identifier )
 
 /* Generated from spec:/rtems/intr/if/lock-reference */
 
@@ -884,15 +884,15 @@ rtems_status_code rtems_interrupt_catch(
  *
  * @brief Defines an ISR lock object reference.
  *
  * @param _designator is the ISR lock reference designator.
  *
  * @param _target is the target object to reference.
  *
  * @par Notes
  * Do not add a ";" after this macro.
  */
-#define RTEMS_INTERRUPT_LOCK_REFERENCE( _designator, _target ) \
-  ISR_LOCK_REFERENCE( _designator, _target )
+#define RTEMS_INTERRUPT_LOCK_REFERENCE( _identifier, _target ) \
+  ISR_LOCK_REFERENCE( _identifier, _target )
 
 /* Generated from spec:/rtems/intr/if/raise */
 
@@ -810,13 +810,13 @@ rtems_status_code rtems_interrupt_catch(
  *   declare, for example ``extern`` or ``static``.
  *
- * @param _designator is the ISR lock object designator.
+ * @param _identifier is the ISR lock object identifier.
  *
  * @par Notes
@@ -828,7 +828,7 @@ rtems_status_code rtems_interrupt_catch(
  *   declare, for example ``extern`` or ``static``.
  *
- * @param _designator is the ISR lock object designator.
+ * @param _identifier is the ISR lock object identifier.
  *
  * @param _name is the ISR lock name.  It shall be a string.  The name is only
@@ -869,13 +869,13 @@ rtems_status_code rtems_interrupt_catch(
  * @brief Defines an ISR lock member.
  *
- * @param _designator is the ISR lock member designator.
+ * @param _identifier is the ISR lock member identifier.
  *
  * @par Notes
@@ -884,15 +884,15 @@ rtems_status_code rtems_interrupt_catch(
  * @brief Defines an ISR lock object reference.
  *
- * @param _designator is the ISR lock reference designator.
+ * @param _identifier is the ISR lock reference identifier.
  *
  * @param _target is the target object to reference.
-- 
2.31.1



More information about the devel mailing list